@@ -403,6 +403,14 @@ def load_libtiepie():
     api.ScpGetData3Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
     api.ScpGetData4Ch.restype = c_uint64
     api.ScpGetData4Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetData5Ch.restype = c_uint64
+    api.ScpGetData5Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetData6Ch.restype = c_uint64
+    api.ScpGetData6Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetData7Ch.restype = c_uint64
+    api.ScpGetData7Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetData8Ch.restype = c_uint64
+    api.ScpGetData8Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
     api.ScpGetValidPreSampleCount.restype = c_uint64
     api.ScpGetValidPreSampleCount.argtypes = [c_uint32]
     api.ScpChGetDataValueRange.restype = None
@@ -421,6 +429,14 @@ def load_libtiepie():
     api.ScpGetDataRaw3Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
     api.ScpGetDataRaw4Ch.restype = c_uint64
     api.ScpGetDataRaw4Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetDataRaw5Ch.restype = c_uint64
+    api.ScpGetDataRaw5Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetDataRaw6Ch.restype = c_uint64
+    api.ScpGetDataRaw6Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetDataRaw7Ch.restype = c_uint64
+    api.ScpGetDataRaw7Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
+    api.ScpGetDataRaw8Ch.restype = c_uint64
+    api.ScpGetDataRaw8Ch.argtypes = [c_uint32, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_uint64, c_uint64]
     api.ScpChGetDataRawType.restype = c_uint32
     api.ScpChGetDataRawType.argtypes = [c_uint32, c_uint16]
     api.ScpChGetDataRawValueRange.restype = None
